package com.ozs.common.core.domain;

import com.ozs.common.constant.HttpStatus;
import com.ozs.common.utils.StringUtils;

import java.util.HashMap;

/**
 * 地址灾害操作消息提醒
 *
 * @author hx
 */
public class Result extends HashMap<String, Object>
{
    private static final long serialVersionUID = 1L;

    /** 状态码 */
    public static final String CODE_TAG = "resultCode";

    /** 返回内容 */
    public static final String MSG_TAG = "message";

    /** 数据对象 */
    public static final String DATA_TAG = "data";

    /**
     * 初始化一个新创建的 AjaxResult 对象，使其表示一个空消息。
     */
    public Result()
    {
    }

    /**
     * 初始化一个新创建的 AjaxResult 对象
     *
     * @param resultCode 状态码
     * @param message 返回内容
     */
    public Result(int resultCode, String message)
    {
        super.put(CODE_TAG, resultCode);
        super.put(MSG_TAG, message);
    }

    /**
     * 初始化一个新创建的 AjaxResult 对象
     *
     * @param resultCode 状态码
     * @param message 返回内容
     * @param data 数据对象
     */
    public Result(int resultCode, String message, Object data)
    {
        super.put(CODE_TAG, resultCode);
        super.put(MSG_TAG, message);
        if (StringUtils.isNotNull(data))
        {
            super.put(DATA_TAG, data);
        }
    }

    /**
     * 返回成功消息
     *
     * @return 成功消息
     */
    public static Result success()
    {
        return Result.success("操作成功");
    }

    /**
     * 返回成功数据
     *
     * @return 成功消息
     */
    public static Result success(Object data)
    {
        return Result.success("操作成功", data);
    }

    /**
     * 返回成功消息
     *
     * @param message 返回内容
     * @return 成功消息
     */
    public static Result success(String message)
    {
        return Result.success(message, null);
    }

    /**
     * 返回成功消息
     *
     * @param message 返回内容
     * @param data 数据对象
     * @return 成功消息
     */
    public static Result success(String message, Object data)
    {
        return new Result(HttpStatus.SUCCESS, message, data);
    }

    /**
     * 返回警告消息
     *
     * @param message 返回内容
     * @return 警告消息
     */
    public static Result warn(String message)
    {
        return Result.warn(message, null);
    }

    /**
     * 返回警告消息
     *
     * @param msg 返回内容
     * @param data 数据对象
     * @return 警告消息
     */
    public static Result warn(String msg, Object data)
    {
        return new Result(HttpStatus.WARN, msg, data);
    }

    /**
     * 返回错误消息
     *
     * @return 错误消息
     */
    public static Result error()
    {
        return Result.error("操作失败");
    }

    /**
     * 返回错误消息
     *
     * @param message 返回内容
     * @return 错误消息
     */
    public static Result error(String message)
    {
        return Result.error(message, null);
    }

    /**
     * 返回错误消息
     *
     * @param message 返回内容
     * @param data 数据对象
     * @return 错误消息
     */
    public static Result error(String message, Object data)
    {
        return new Result(HttpStatus.ERROR, message, data);
    }

    /**
     * 返回错误消息
     *
     * @param resultCode 状态码
     * @param message 返回内容
     * @return 错误消息
     */
    public static Result error(int resultCode, String message)
    {
        return new Result(resultCode, message, null);
    }

    /**
     * 方便链式调用
     *
     * @param key 键
     * @param value 值
     * @return 数据对象
     */
    @Override
    public Result put(String key, Object value)
    {
        super.put(key, value);
        return this;
    }
}
