package com.ozs.framework.config;

import com.baomidou.mybatisplus.annotation.DbType;
import com.baomidou.mybatisplus.extension.plugins.MybatisPlusInterceptor;
import com.baomidou.mybatisplus.extension.plugins.inner.PaginationInnerInterceptor;
import com.ozs.framework.config.properties.DruidProperties;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;


@Configuration
@ComponentScan("com.ozs")
@MapperScan("com.ozs.*.mapper")
public class CipherMybatisPlusConfig {

    @Value("${base.sql-type:mysql}")
    private String type;

    @Value("${base.dbname:vehicle}")
    private String dbname;

    @Bean
    public MybatisPlusInterceptor mybatisPlusInterceptor() {
        MybatisPlusInterceptor interceptor = new MybatisPlusInterceptor();

        // 自定义拦截器，先添加先执行。
        if (type.equals(DbType.POSTGRE_SQL.getDb())) {
            interceptor.addInnerInterceptor(new PostgreSqlMybatisIntercepts());
        }
        // 自定义拦截器，先添加先执行。
        if (type.equals(DbType.KINGBASE_ES.getDb())) {
            interceptor.addInnerInterceptor(new KindBaseSqlMybatisIntercepts(dbname));
        }

        // 自带分页拦截器
//        interceptor.addInnerInterceptor(new PaginationInnerInterceptor(DbType.getDbType(type)));
        return interceptor;
    }


}
